@@ -1,5 +1,5 @@
 # from xtable package
-ascii.ts <- function (x, include.rownames = TRUE, include.colnames = TRUE, rownames = NULL, colnames = NULL, format = "f", digits = 0, decimal.mark = ".", na.print = "", caption = "", caption.level = "", width = 0, frame = "", grid = "", valign = "", header = TRUE, footer = FALSE, align = "", col.width = 1, style = "", cgroup = NULL, n.cgroup = NULL, calign = "", cvalign = "", cstyle = "", rgroup = NULL, n.rgroup = NULL, ralign = "", rvalign = "", rstyle = "", ...){
+ascii.ts <- function (x, include.rownames = TRUE, include.colnames = TRUE, rownames = NULL, colnames = NULL, format = "f", digits = 0, decimal.mark = ".", na.print = "", caption = "", caption.level = "", width = 0, frame = "", grid = "", valign = "", header = TRUE, footer = FALSE, align = "", col.width = 1, style = "", tgroup = NULL, n.tgroup = NULL, talign = "", tvalign = "", tstyle = "", bgroup = NULL, n.bgroup = NULL, balign = "", bvalign = "", bstyle = "", lgroup = NULL, n.lgroup = NULL, lalign = "", lvalign = "", lstyle = "", rgroup = NULL, n.rgroup = NULL, ralign = "", rvalign = "", rstyle = "", ...){
 
   if (inherits(x, "ts") && !is.null(ncol(x))) {
     tp.1 <- trunc(time(x))
@@ -35,8 +35,13 @@ ascii.ts <- function (x, include.rownames = TRUE, include.colnames = TRUE, rowna
       format = format, digits = digits, decimal.mark = decimal.mark, na.print = na.print,
       caption = caption, caption.level = caption.level, width = width, frame = frame,
       grid = grid, valign = valign, header = header, footer = footer, align = align,
-      col.width = col.width, style = style, cgroup = cgroup, n.cgroup = n.cgroup,
-      calign = calign, cvalign = cvalign, cstyle = cstyle,
+      col.width = col.width, style = style,
+      tgroup = tgroup, n.tgroup = n.tgroup, talign = talign,
+      tvalign = tvalign, tstyle = tstyle,
+      bgroup = bgroup, n.bgroup = n.bgroup, balign = balign,
+      bvalign = bvalign, bstyle = bstyle,
+      lgroup = lgroup, n.lgroup = n.lgroup, lalign = lalign,
+      lvalign = lvalign, lstyle = lstyle,
       rgroup = rgroup, n.rgroup = n.rgroup, ralign = ralign,
       rvalign = rvalign, rstyle = rstyle)
   class(obj) <- c("ascii", "proto", "environment")
